@@ -1193,7 +1193,7 @@ export class HeSetupModel {
                 self.addValuesToModel(gDeployAnswerFile, model);
                 model.storage.domainType.value = "glusterfs";
                 model.storage.enableHcGlusterService.value = true;
-                console.log("Gluster values successfully added: ",gdeployHeAnsFilePath);
+                console.log("Gluster values successfully added.");
             })
             .fail(function(error) {
                 console.log("Failed to read the gluster answer file. " + error);
